@@ -50,7 +50,7 @@ class Exceptions:
 
 class RDSDataServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html)
     """
 
@@ -68,25 +68,25 @@ class RDSDataServiceClient(BaseClient):
         resourceArn: str,
         secretArn: str,
         sql: str,
-        database: str = None,
-        parameterSets: Sequence[Sequence["SqlParameterTypeDef"]] = None,
-        schema: str = None,
-        transactionId: str = None
+        database: str = ...,
+        parameterSets: Sequence[Sequence["SqlParameterTypeDef"]] = ...,
+        schema: str = ...,
+        transactionId: str = ...
     ) -> BatchExecuteStatementResponseTypeDef:
         """
         Runs a batch SQL statement over an array of data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#batch_execute_statement)
         """
 
     def begin_transaction(
-        self, *, resourceArn: str, secretArn: str, database: str = None, schema: str = None
+        self, *, resourceArn: str, secretArn: str, database: str = ..., schema: str = ...
     ) -> BeginTransactionResponseTypeDef:
         """
         Starts a SQL transaction.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#begin_transaction)
         """
 
@@ -94,7 +94,7 @@ class RDSDataServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#can_paginate)
         """
 
@@ -105,7 +105,7 @@ class RDSDataServiceClient(BaseClient):
         Ends a SQL transaction started with the `BeginTransaction` operation and commits
         the changes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#commit_transaction)
         """
 
@@ -115,13 +115,13 @@ class RDSDataServiceClient(BaseClient):
         awsSecretStoreArn: str,
         dbClusterOrInstanceArn: str,
         sqlStatements: str,
-        database: str = None,
-        schema: str = None
+        database: str = ...,
+        schema: str = ...
     ) -> ExecuteSqlResponseTypeDef:
         """
         Runs one or more SQL statements.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute_sql)
         """
 
@@ -131,32 +131,32 @@ class RDSDataServiceClient(BaseClient):
         resourceArn: str,
         secretArn: str,
         sql: str,
-        continueAfterTimeout: bool = None,
-        database: str = None,
-        includeResultMetadata: bool = None,
-        parameters: Sequence["SqlParameterTypeDef"] = None,
-        resultSetOptions: "ResultSetOptionsTypeDef" = None,
-        schema: str = None,
-        transactionId: str = None
+        continueAfterTimeout: bool = ...,
+        database: str = ...,
+        includeResultMetadata: bool = ...,
+        parameters: Sequence["SqlParameterTypeDef"] = ...,
+        resultSetOptions: "ResultSetOptionsTypeDef" = ...,
+        schema: str = ...,
+        transactionId: str = ...
     ) -> ExecuteStatementResponseTypeDef:
         """
         Runs a SQL statement against a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute_statement)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#generate_presigned_url)
         """
 
@@ -166,6 +166,6 @@ class RDSDataServiceClient(BaseClient):
         """
         Performs a rollback of a transaction.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#rollback_transaction)
         """
